@@ -53,7 +53,7 @@ class ExecutionServer(BaseServer):
             name=None,
             time_offset=None,
             peer_check_interval=60,
-            reservation_check_interval=60,
+            reservation_check_interval=5,
             hammer_prevention=False):
         if name == None:
             name = "AWSpider Execution Server UUID: %s" % self.uuid
@@ -439,8 +439,10 @@ class ExecutionServer(BaseServer):
 
     def query(self, data=None):
         if len(self.job_queue) > 100:
+            LOGGER.debug("Skipping query. %s jobs already active." % len(self.job_queue))
             return
         if self.querying_for_jobs:
+            LOGGER.debug("Skipping query. Already querying for jobs.")
             return
         self.querying_for_jobs = True
         if self.uuid_limits["start"] is None and self.uuid_limits["end"] is not None:
